xkcd: Desert Island

- Archive
- What If?
- Blag
- Store
- About

A webcomic of romance,
sarcasm, math, and language.
xkcd updates every Monday, Wednesday, and Friday.
Desert Island

- |<
- < Prev
- Random
- Next >
- >|

- |<
- < Prev
- Random
- Next >
- >|

Permanent link to this comic: https://xkcd.com/731/
Image URL (for hotlinking/embedding): https://imgs.xkcd.com/comics/desert_island.png
[[A man sits writing in a diary on a desert island, only the sandy tip of which with a palm tree on it stands above the water. Beneath the surface is a kelp forest, some sharks, a stingray, a shipwreck, a submarine, several large jellyfish, a giant squid fighting a sperm whale, a crashed plane, some coral formations, a thermal vent emitting a plume of smoke surrounded by several annelids, and a snail.]] Man: Day 44: Still stranded, with nothing but flat empty water as far as the eye can see. {{Title text: Telescopes and bathyscapes and sonar probes of Scottish lakes, Tacoma Narrows bridge collapse explained with abstract phase-space maps, some x-ray slides, a music score, Minard's Napoleonic war: the most exciting new frontier is charting what's already here.}}
RSS Feed - Atom Feed
Comics I enjoy:
Three Word Phrase, SMBC, Dinosaur Comics, Oglaf (nsfw), A Softer World, Buttersafe, Perry Bible Fellowship, Questionable Content, Buttercup Festival, Homestuck, Junior Scientist Power Hour,
Other things:
Women Also Know Stuff, Tech Solidarity, Tips on technology and government
xkcd.com is best viewed with Netscape Navigator 4.0 or below on a Pentium 3±1 emulated in Javascript on an Apple IIGS
at a screen resolution of 1024x1. Please enable your ad blockers, disable high-heat drying, and remove your device
from Airplane Mode and set it to Boat Mode. For security reasons, please leave caps lock on while browsing.

This work is licensed under a Creative Commons Attribution-NonCommercial 2.5 License.

This means you're free to copy and share these comics (but not to sell them). More details.